Scope Methods — Rucio 0.3.8 documentation

# Scope Methods

class `rucio.client.scopeclient.` `ScopeClient`(rucio_host=None, auth_host=None, account=None, ca_cert=None, auth_type=None, creds=None, timeout=None, user_agent='rucio-clients')

  Bases: `rucio.client.baseclient.BaseClient`

  Scope client class for working with rucio scopes

  `SCOPE_BASEURL` = 'accounts'
  `add_scope`(account, scope)

    Sends the request to add a new scope.

    Parameters: | account – the name of the account to add the scope to. scope – the name of the new scope.
    Returns: | True if scope was created successfully.
    Raises: | Duplicate – if scope already exists. AccountNotFound – if account doesn’t exist.

  `list_scopes`()

    Sends the request to list all scopes.

    Returns: | a list containing the names of all scopes.

  `list_scopes_for_account`(account)

    Sends the request to list all scopes for a rucio account.

    Parameters: | account – the rucio account to list scopes for.
    Returns: | a list containing the names of all scopes for a rucio account.
    Raises: | AccountNotFound – if account doesn’t exist. ScopeNotFound – if no scopes exist for account.